Changelog
---------

A list of changes between each release.

0.3.3 (2014-6-06)
^^^^^^^^^^^^^^^^^^^

- Fix problem with PyPi package.

0.3.2 (2014-6-06)
^^^^^^^^^^^^^^^^^^^

- Fix issue with PyPI package.
- Code refactoring

0.3.1 (2014-6-05)
^^^^^^^^^^^^^^^^^^^

- Fix incorrect wrapping that fine-grained progress introduced

0.3.0 (2014-6-05)
^^^^^^^^^^^^^^^^^^^

- Fine-grained progressbar using more Unicode block chars
- Display version of pytest and pytest-sugar
- Python 3 support
- Fix GH-3: Wrap tests when they extend past line
